/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigCore.h"

#include <kcoreconfigskeleton.h>

#include <qstring.h>
#include <qobject.h>
#include <kcoreconfigskeleton.h>
#include <qlist.h>
#include <kconfig.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qlist.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qstringlist.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qdatetime.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qsize.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qpoint.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qrect.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qvariant.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qmetaobject.h>
#include <qcoreevent.h>
#include <qcoreevent.h>
#include <qcoreevent.h>
#include <qlist.h>
#include <qbytearray.h>
#include <qlist.h>
#include <qnamespace.h>
#include <qthread.h>
#include <qnamespace.h>
#include <qregexp.h>
#include <qregularexpression.h>
#include <qobjectdefs.h>


class sipKCoreConfigSkeleton : public  ::KCoreConfigSkeleton
{
public:
    sipKCoreConfigSkeleton(const  ::QString&, ::QObject*);
    virtual ~sipKCoreConfigSkeleton();

    int qt_metacall(QMetaObject::Call,int,void **);
    void *qt_metacast(const char *);
    const QMetaObject *metaObject() const;

    /*
     * There is a public method for every protected method visible from
     * this class.
     */
     ::QObject* sipProtect_sender() const;
    int sipProtect_receivers(const char*) const;
    void sipProtectVirt_timerEvent(bool, ::QTimerEvent*);
    void sipProtectVirt_childEvent(bool, ::QChildEvent*);
    void sipProtectVirt_customEvent(bool, ::QEvent*);
    void sipProtectVirt_connectNotify(bool,const  ::QMetaMethod&);
    void sipProtectVirt_disconnectNotify(bool,const  ::QMetaMethod&);
    int sipProtect_senderSignalIndex() const;
    bool sipProtect_isSignalConnected(const  ::QMetaMethod&) const;
    bool sipProtectVirt_usrUseDefaults(bool,bool);
    void sipProtectVirt_usrSetDefaults(bool);
    void sipProtectVirt_usrRead(bool);
    bool sipProtectVirt_usrSave(bool);
    void sipProtectVirt_usrReadConfig(bool);
    bool sipProtectVirt_usrWriteConfig(bool);

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool usrWriteConfig();
    void usrReadConfig();
    bool usrSave();
    void usrRead();
    void usrSetDefaults();
    bool usrUseDefaults(bool);
    bool useDefaults(bool);
    void setDefaults();
    bool event( ::QEvent*);
    bool eventFilter( ::QObject*, ::QEvent*);
    void timerEvent( ::QTimerEvent*);
    void childEvent( ::QChildEvent*);
    void customEvent( ::QEvent*);
    void connectNotify(const  ::QMetaMethod&);
    void disconnectNotify(const  ::QMetaMethod&);

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipKCoreConfigSkeleton(const sipKCoreConfigSkeleton &);
    sipKCoreConfigSkeleton &operator = (const sipKCoreConfigSkeleton &);

    char sipPyMethods[15];
};

sipKCoreConfigSkeleton::sipKCoreConfigSkeleton(const  ::QString& a0, ::QObject*a1):  ::KCoreConfigSkeleton(a0,a1), sipPySelf(0)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipKCoreConfigSkeleton::~sipKCoreConfigSkeleton()
{
    sipInstanceDestroyed(sipPySelf);
}

const QMetaObject *sipKCoreConfigSkeleton::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_KConfigCore_qt_metaobject(sipPySelf,sipType_KCoreConfigSkeleton);

    return  ::KCoreConfigSkeleton::metaObject();
}

int sipKCoreConfigSkeleton::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::KCoreConfigSkeleton::qt_metacall(_c,_id,_a);

    if (_id >= 0)
        _id = sip_KConfigCore_qt_metacall(sipPySelf,sipType_KCoreConfigSkeleton,_c,_id,_a);

    return _id;
}

void *sipKCoreConfigSkeleton::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_KConfigCore_qt_metacast(sipPySelf, sipType_KCoreConfigSkeleton, _clname, &sipCpp) ? sipCpp :  ::KCoreConfigSkeleton::qt_metacast(_clname));
}

bool sipKCoreConfigSkeleton::usrWriteConfig()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,NULL,sipName_usrWriteConfig);

    if (!sipMeth)
        return  ::KCoreConfigSkeleton::usrWriteConfig();

    extern bool sipVH_KConfigCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_1(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipKCoreConfigSkeleton::usrReadConfig()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,NULL,sipName_usrReadConfig);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::usrReadConfig();
        return;
    }

    extern void sipVH_KConfigCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigCore_2(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipKCoreConfigSkeleton::usrSave()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,NULL,sipName_usrSave);

    if (!sipMeth)
        return  ::KCoreConfigSkeleton::usrSave();

    extern bool sipVH_KConfigCore_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigCore_1(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipKCoreConfigSkeleton::usrRead()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,NULL,sipName_usrRead);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::usrRead();
        return;
    }

    extern void sipVH_KConfigCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigCore_2(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipKCoreConfigSkeleton::usrSetDefaults()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,NULL,sipName_usrSetDefaults);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::usrSetDefaults();
        return;
    }

    extern void sipVH_KConfigCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigCore_2(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipKCoreConfigSkeleton::usrUseDefaults(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,NULL,sipName_usrUseDefaults);

    if (!sipMeth)
        return  ::KCoreConfigSkeleton::usrUseDefaults(a0);

    extern bool sipVH_KConfigCore_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_KConfigCore_19(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipKCoreConfigSkeleton::useDefaults(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,NULL,sipName_useDefaults);

    if (!sipMeth)
        return  ::KCoreConfigSkeleton::useDefaults(a0);

    extern bool sipVH_KConfigCore_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_KConfigCore_19(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKCoreConfigSkeleton::setDefaults()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,NULL,sipName_setDefaults);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::setDefaults();
        return;
    }

    extern void sipVH_KConfigCore_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigCore_2(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipKCoreConfigSkeleton::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,NULL,sipName_event);

    if (!sipMeth)
        return  ::KCoreConfigSkeleton::event(a0);

    extern bool sipVH_KConfigCore_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_KConfigCore_18(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipKCoreConfigSkeleton::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,NULL,sipName_eventFilter);

    if (!sipMeth)
        return  ::KCoreConfigSkeleton::eventFilter(a0,a1);

    extern bool sipVH_KConfigCore_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_KConfigCore_17(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipKCoreConfigSkeleton::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[10],sipPySelf,NULL,sipName_timerEvent);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::timerEvent(a0);
        return;
    }

    extern void sipVH_KConfigCore_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_KConfigCore_16(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKCoreConfigSkeleton::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[11],sipPySelf,NULL,sipName_childEvent);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::childEvent(a0);
        return;
    }

    extern void sipVH_KConfigCore_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_KConfigCore_15(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKCoreConfigSkeleton::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[12],sipPySelf,NULL,sipName_customEvent);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::customEvent(a0);
        return;
    }

    extern void sipVH_KConfigCore_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_KConfigCore_14(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKCoreConfigSkeleton::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[13],sipPySelf,NULL,sipName_connectNotify);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::connectNotify(a0);
        return;
    }

    extern void sipVH_KConfigCore_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_KConfigCore_13(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKCoreConfigSkeleton::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[14],sipPySelf,NULL,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::KCoreConfigSkeleton::disconnectNotify(a0);
        return;
    }

    extern void sipVH_KConfigCore_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_KConfigCore_13(sipGILState, sipImportedVirtErrorHandlers_KConfigCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

 ::QObject* sipKCoreConfigSkeleton::sipProtect_sender() const
{
    return  ::QObject::sender();
}

int sipKCoreConfigSkeleton::sipProtect_receivers(const char*a0) const
{
    return  ::QObject::receivers(a0);
}

void sipKCoreConfigSkeleton::sipProtectVirt_timerEvent(bool sipSelfWasArg, ::QTimerEvent*a0)
{
    (sipSelfWasArg ?  ::QObject::timerEvent(a0) : timerEvent(a0));
}

void sipKCoreConfigSkeleton::sipProtectVirt_childEvent(bool sipSelfWasArg, ::QChildEvent*a0)
{
    (sipSelfWasArg ?  ::QObject::childEvent(a0) : childEvent(a0));
}

void sipKCoreConfigSkeleton::sipProtectVirt_customEvent(bool sipSelfWasArg, ::QEvent*a0)
{
    (sipSelfWasArg ?  ::QObject::customEvent(a0) : customEvent(a0));
}

void sipKCoreConfigSkeleton::sipProtectVirt_connectNotify(bool sipSelfWasArg,const  ::QMetaMethod& a0)
{
    (sipSelfWasArg ?  ::QObject::connectNotify(a0) : connectNotify(a0));
}

void sipKCoreConfigSkeleton::sipProtectVirt_disconnectNotify(bool sipSelfWasArg,const  ::QMetaMethod& a0)
{
    (sipSelfWasArg ?  ::QObject::disconnectNotify(a0) : disconnectNotify(a0));
}

int sipKCoreConfigSkeleton::sipProtect_senderSignalIndex() const
{
    return  ::QObject::senderSignalIndex();
}

bool sipKCoreConfigSkeleton::sipProtect_isSignalConnected(const  ::QMetaMethod& a0) const
{
    return  ::QObject::isSignalConnected(a0);
}

bool sipKCoreConfigSkeleton::sipProtectVirt_usrUseDefaults(bool sipSelfWasArg,bool a0)
{
    return (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrUseDefaults(a0) : usrUseDefaults(a0));
}

void sipKCoreConfigSkeleton::sipProtectVirt_usrSetDefaults(bool sipSelfWasArg)
{
    (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrSetDefaults() : usrSetDefaults());
}

void sipKCoreConfigSkeleton::sipProtectVirt_usrRead(bool sipSelfWasArg)
{
    (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrRead() : usrRead());
}

bool sipKCoreConfigSkeleton::sipProtectVirt_usrSave(bool sipSelfWasArg)
{
    return (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrSave() : usrSave());
}

void sipKCoreConfigSkeleton::sipProtectVirt_usrReadConfig(bool sipSelfWasArg)
{
    (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrReadConfig() : usrReadConfig());
}

bool sipKCoreConfigSkeleton::sipProtectVirt_usrWriteConfig(bool sipSelfWasArg)
{
    return (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrWriteConfig() : usrWriteConfig());
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_sender(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_sender(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;

    {
        const sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
             ::QObject*sipRes = 0;

        // sender() must be called without the GIL to avoid possible deadlocks between
        // the GIL and Qt's internal thread data mutex.
        
        Py_BEGIN_ALLOW_THREADS
        
        #if defined(SIP_PROTECTED_IS_PUBLIC)
        sipRes = sipCpp->sender();
        #else
        sipRes = sipCpp->sipProtect_sender();
        #endif
        
        Py_END_ALLOW_THREADS
        
        if (!sipRes)
        {
            typedef QObject *(*qtcore_qobject_sender_t)();
        
            static qtcore_qobject_sender_t qtcore_qobject_sender = 0;
        
            if (!qtcore_qobject_sender)
            {
                qtcore_qobject_sender = (qtcore_qobject_sender_t)sipImportSymbol("qtcore_qobject_sender");
                Q_ASSERT(qtcore_qobject_sender);
            }
        
            sipRes = qtcore_qobject_sender();
        }

            return sipConvertFromType(sipRes,sipType_QObject,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_sender, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_receivers(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_receivers(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;

    {
        PyObject * a0;
        const sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BP0", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, &a0))
        {
            int sipRes = 0;
            sipErrorState sipError = sipErrorNone;

        // We need to handle the signal object.  Import the helper if it hasn't already
        // been done.
        typedef sipErrorState (*pyqt5_get_signal_signature_t)(PyObject *, const QObject *, const QByteArray &);
        
        static pyqt5_get_signal_signature_t pyqt5_get_signal_signature = 0;
        
        if (!pyqt5_get_signal_signature)
        {
            pyqt5_get_signal_signature = (pyqt5_get_signal_signature_t)sipImportSymbol("pyqt5_get_signal_signature");
            Q_ASSERT(pyqt5_get_signal_signature);
        }
        
        QByteArray signal_signature;
            
        #if defined(SIP_PROTECTED_IS_PUBLIC)
        if ((sipError = pyqt5_get_signal_signature(a0, sipCpp, signal_signature)) == sipErrorNone)
        {
            sipRes = sipCpp->receivers(signal_signature.constData());
        }
        #else
        if ((sipError = pyqt5_get_signal_signature(a0, static_cast<const QObject *>(sipCpp), signal_signature)) == sipErrorNone)
        {
            sipRes = sipCpp->sipProtect_receivers(signal_signature.constData());
        }
        #endif
        else if (sipError == sipErrorContinue)
        {
            sipError = sipBadCallableArg(0, a0);
        }

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return SIPLong_FromLong(sipRes);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_receivers, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_timerEvent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_timerEvent(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QTimerEvent* a0;
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ8", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QTimerEvent, &a0))
        {
            sipCpp->sipProtectVirt_timerEvent(sipSelfWasArg,a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_timerEvent, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_childEvent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_childEvent(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QChildEvent* a0;
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ8", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QChildEvent, &a0))
        {
            sipCpp->sipProtectVirt_childEvent(sipSelfWasArg,a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_childEvent, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_customEvent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_customEvent(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QEvent* a0;
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ8", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QEvent, &a0))
        {
            sipCpp->sipProtectVirt_customEvent(sipSelfWasArg,a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_customEvent, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_connectNotify(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_connectNotify(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QMetaMethod* a0;
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ9", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QMetaMethod, &a0))
        {
            sipCpp->sipProtectVirt_connectNotify(sipSelfWasArg,*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_connectNotify, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_disconnectNotify(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_disconnectNotify(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QMetaMethod* a0;
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ9", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QMetaMethod, &a0))
        {
            sipCpp->sipProtectVirt_disconnectNotify(sipSelfWasArg,*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_disconnectNotify, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_senderSignalIndex(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_senderSignalIndex(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;

    {
        const sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sipProtect_senderSignalIndex();

            return SIPLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_senderSignalIndex, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_isSignalConnected(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_isSignalConnected(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QMetaMethod* a0;
        const sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ9", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QMetaMethod, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->sipProtect_isSignalConnected(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_isSignalConnected, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_setDefaults(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_setDefaults(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp-> ::KCoreConfigSkeleton::setDefaults() : sipCpp->setDefaults());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_setDefaults, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_load(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_load(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            sipCpp->load();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_load, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_readConfig(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_readConfig(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            sipCpp->readConfig();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_readConfig, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_read(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_read(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            sipCpp->read();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_read, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_setCurrentGroup(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_setCurrentGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->setCurrentGroup(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_setCurrentGroup, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_currentGroup(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_currentGroup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
             ::QString*sipRes;

            sipRes = new  ::QString(sipCpp->currentGroup());

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_currentGroup, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItem(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KConfigSkeletonItem* a0;
        const  ::QString& a1def = QString();
        const  ::QString* a1 = &a1def;
        int a1State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8|J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_KConfigSkeletonItem, &a0, sipType_QString,&a1, &a1State))
        {
            sipCpp->addItem(a0,*a1);
            sipReleaseType(const_cast< ::QString *>(a1),sipType_QString,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItem, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemString(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QString* a1;
        int a1State = 0;
        const  ::QString& a2def = QLatin1String("");
        const  ::QString* a2 = &a2def;
        int a2State = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1|J1J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QString,&a1, &a1State, sipType_QString,&a2, &a2State, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemString*sipRes;

            sipRes = sipCpp->addItemString(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a1,sipType_QString,a1State);
            sipReleaseType(const_cast< ::QString *>(a2),sipType_QString,a2State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemString, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemPassword(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemPassword(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QString* a1;
        int a1State = 0;
        const  ::QString& a2def = QLatin1String("");
        const  ::QString* a2 = &a2def;
        int a2State = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1|J1J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QString,&a1, &a1State, sipType_QString,&a2, &a2State, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemPassword*sipRes;

            sipRes = sipCpp->addItemPassword(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a1,sipType_QString,a1State);
            sipReleaseType(const_cast< ::QString *>(a2),sipType_QString,a2State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemPassword,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemPassword, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemPath(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QString* a1;
        int a1State = 0;
        const  ::QString& a2def = QLatin1String("");
        const  ::QString* a2 = &a2def;
        int a2State = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1|J1J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QString,&a1, &a1State, sipType_QString,&a2, &a2State, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemPath*sipRes;

            sipRes = sipCpp->addItemPath(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a1,sipType_QString,a1State);
            sipReleaseType(const_cast< ::QString *>(a2),sipType_QString,a2State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemPath,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemPath, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemProperty(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemProperty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QVariant* a1;
        int a1State = 0;
        const  ::QVariant& a2def = QVariant();
        const  ::QVariant* a2 = &a2def;
        int a2State = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1|J1J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QVariant, &a1, &a1State, sipType_QVariant, &a2, &a2State, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemProperty*sipRes;

            sipRes = sipCpp->addItemProperty(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a1,sipType_QVariant,a1State);
            sipReleaseType(const_cast< ::QVariant *>(a2),sipType_QVariant,a2State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemProperty,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemProperty, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemBool(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemBool(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        bool a1;
        bool a2 = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1|bJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemBool*sipRes = 0;

    sipRes = new PyItemBool (sipCpp->currentGroup(), a3->isNull() ? *a0 : *a3, a1, a2);
    sipCpp->addItem(sipRes, *a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            PyObject *sipResObj = sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemBool,NULL);
            return sipBuildResult(0,"(Rb)",sipResObj,a1);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemBool, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemInt(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemInt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        int a1;
        int a2 = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1|iJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemInt*sipRes = 0;

    sipRes = new PyItemInt (sipCpp->currentGroup(), a3->isNull() ? *a0 : *a3, a1, a2);
    sipCpp->addItem(sipRes, *a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            PyObject *sipResObj = sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemInt,NULL);
            return sipBuildResult(0,"(Ri)",sipResObj,a1);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemInt, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemUInt(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemUInt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        uint a1;
        uint a2 = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1|uJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemUInt*sipRes = 0;

    sipRes = new PyItemUInt (sipCpp->currentGroup(), a3->isNull() ? *a0 : *a3, a1, a2);
    sipCpp->addItem(sipRes, *a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            PyObject *sipResObj = sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemUInt,NULL);
            return sipBuildResult(0,"(Ru)",sipResObj,a1);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemUInt, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemLongLong(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemLongLong(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        PY_LONG_LONG a1;
        PY_LONG_LONG a2 = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1|nJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemLongLong*sipRes = 0;

    sipRes = new PyItemLongLong (sipCpp->currentGroup(), a3->isNull() ? *a0 : *a3, a1, a2);
    sipCpp->addItem(sipRes, *a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            PyObject *sipResObj = sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemLongLong,NULL);
            return sipBuildResult(0,"(Rn)",sipResObj,a1);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemLongLong, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemInt64(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemInt64(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        PY_LONG_LONG a1;
        PY_LONG_LONG a2 = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1|nJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemLongLong*sipRes = 0;

    sipRes = new PyItemLongLong (sipCpp->currentGroup(), a3->isNull() ? *a0 : *a3, a1, a2);
    sipCpp->addItem(sipRes, *a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            PyObject *sipResObj = sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemLongLong,NULL);
            return sipBuildResult(0,"(Rn)",sipResObj,a1);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemInt64, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemULongLong(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemULongLong(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        unsigned PY_LONG_LONG a1;
        unsigned PY_LONG_LONG a2 = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1|oJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemULongLong*sipRes = 0;

    sipRes = new PyItemULongLong (sipCpp->currentGroup(), a3->isNull() ? *a0 : *a3, a1, a2);
    sipCpp->addItem(sipRes, *a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            PyObject *sipResObj = sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemULongLong,NULL);
            return sipBuildResult(0,"(Ro)",sipResObj,a1);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemULongLong, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemUInt64(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemUInt64(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        unsigned PY_LONG_LONG a1;
        unsigned PY_LONG_LONG a2 = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1|oJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemULongLong*sipRes = 0;

    sipRes = new PyItemULongLong (sipCpp->currentGroup(), a3->isNull() ? *a0 : *a3, a1, a2);
    sipCpp->addItem(sipRes, *a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            PyObject *sipResObj = sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemULongLong,NULL);
            return sipBuildResult(0,"(Ro)",sipResObj,a1);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemUInt64, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemDouble(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemDouble(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        double a1;
        double a2 = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1|dJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemDouble*sipRes = 0;

    sipRes = new PyItemDouble (sipCpp->currentGroup(), a3->isNull() ? *a0 : *a3, a1, a2);
    sipCpp->addItem(sipRes, *a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            PyObject *sipResObj = sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemDouble,NULL);
            return sipBuildResult(0,"(Rd)",sipResObj,a1);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemDouble, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemRect(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QRect* a1;
        const  ::QRect& a2def = QRect();
        const  ::QRect* a2 = &a2def;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9|J9J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QRect, &a1, sipType_QRect, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemRect*sipRes;

            sipRes = sipCpp->addItemRect(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemRect,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemRect, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemPoint(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QPoint* a1;
        const  ::QPoint& a2def = QPoint();
        const  ::QPoint* a2 = &a2def;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9|J9J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QPoint, &a1, sipType_QPoint, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemPoint*sipRes;

            sipRes = sipCpp->addItemPoint(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemPoint,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemPoint, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemSize(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QSize* a1;
        const  ::QSize& a2def = QSize();
        const  ::QSize* a2 = &a2def;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9|J9J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QSize, &a1, sipType_QSize, &a2, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemSize*sipRes;

            sipRes = sipCpp->addItemSize(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemSize,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemSize, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemDateTime(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemDateTime(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QDateTime* a1;
        int a1State = 0;
        const  ::QDateTime& a2def = QDateTime();
        const  ::QDateTime* a2 = &a2def;
        int a2State = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1|J1J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QDateTime, &a1, &a1State, sipType_QDateTime, &a2, &a2State, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemDateTime*sipRes;

            sipRes = sipCpp->addItemDateTime(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a1,sipType_QDateTime,a1State);
            sipReleaseType(const_cast< ::QDateTime *>(a2),sipType_QDateTime,a2State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemDateTime,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemDateTime, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemStringList(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemStringList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QStringList* a1;
        int a1State = 0;
        const  ::QStringList& a2def = QStringList();
        const  ::QStringList* a2 = &a2def;
        int a2State = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1|J1J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QStringList,&a1, &a1State, sipType_QStringList,&a2, &a2State, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemStringList*sipRes;

            sipRes = sipCpp->addItemStringList(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a1,sipType_QStringList,a1State);
            sipReleaseType(const_cast< ::QStringList *>(a2),sipType_QStringList,a2State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemStringList,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemStringList, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_addItemIntList(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_addItemIntList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QList<int>* a1;
        int a1State = 0;
        const  ::QList<int>& a2def = QList<int>();
        const  ::QList<int>* a2 = &a2def;
        int a2State = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1|J1J1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QList_1800,&a1, &a1State, sipType_QList_1800,&a2, &a2State, sipType_QString,&a3, &a3State))
        {
             ::KCoreConfigSkeleton::ItemIntList*sipRes;

            sipRes = sipCpp->addItemIntList(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a1,sipType_QList_1800,a1State);
            sipReleaseType(const_cast< ::QList<int> *>(a2),sipType_QList_1800,a2State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KCoreConfigSkeleton_ItemIntList,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_addItemIntList, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_config(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_config(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
             ::KConfig*sipRes;

            sipRes = sipCpp->config();

            return sipConvertFromType(sipRes,sipType_KConfig,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_config, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_items(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_items(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
             ::KConfigSkeletonItem::List*sipRes;

            sipRes = new  ::KConfigSkeletonItem::List(sipCpp->items());

            return sipConvertFromNewType(sipRes,sipType_QList_0101KConfigSkeletonItem,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_items, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_removeItem(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_removeItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State))
        {
            sipCpp->removeItem(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_removeItem, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_clearItems(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_clearItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            sipCpp->clearItems();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_clearItems, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_isImmutable(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_isImmutable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->isImmutable(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_isImmutable, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_findItem(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_findItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
        const  ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State))
        {
             ::KConfigSkeletonItem*sipRes;

            sipRes = sipCpp->findItem(*a0);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            return sipConvertFromType(sipRes,sipType_KConfigSkeletonItem,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_findItem, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_useDefaults(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_useDefaults(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp-> ::KCoreConfigSkeleton::useDefaults(a0) : sipCpp->useDefaults(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_useDefaults, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_save(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_save(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->save();

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_save, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_writeConfig(PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_writeConfig(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KCoreConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            sipCpp->writeConfig();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_writeConfig, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_usrUseDefaults(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_usrUseDefaults(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "Bb", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->sipProtectVirt_usrUseDefaults(sipSelfWasArg,a0);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_usrUseDefaults, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_usrSetDefaults(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_usrSetDefaults(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            sipCpp->sipProtectVirt_usrSetDefaults(sipSelfWasArg);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_usrSetDefaults, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_usrRead(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_usrRead(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            sipCpp->sipProtectVirt_usrRead(sipSelfWasArg);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_usrRead, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_usrSave(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_usrSave(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->sipProtectVirt_usrSave(sipSelfWasArg);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_usrSave, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_usrReadConfig(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_usrReadConfig(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            sipCpp->sipProtectVirt_usrReadConfig(sipSelfWasArg);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_usrReadConfig, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KCoreConfigSkeleton_usrWriteConfig(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KCoreConfigSkeleton_usrWriteConfig(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        sipKCoreConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KCoreConfigSkeleton, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->sipProtectVirt_usrWriteConfig(sipSelfWasArg);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KCoreConfigSkeleton, sipName_usrWriteConfig, NULL);

    return NULL;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_KCoreConfigSkeleton(void *, const sipTypeDef *);}
static void *cast_KCoreConfigSkeleton(void *sipCppV, const sipTypeDef *targetType)
{
     ::KCoreConfigSkeleton *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_KCoreConfigSkeleton(void *, int);}
static void release_KCoreConfigSkeleton(void *sipCppV, int)
{
     ::KCoreConfigSkeleton *sipCpp = reinterpret_cast< ::KCoreConfigSkeleton *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_KCoreConfigSkeleton(sipSimpleWrapper *);}
static void dealloc_KCoreConfigSkeleton(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipKCoreConfigSkeleton *>(sipGetAddress(sipSelf))->sipPySelf = NULL;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_KCoreConfigSkeleton(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_KCoreConfigSkeleton(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_KCoreConfigSkeleton(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipKCoreConfigSkeleton *sipCpp = 0;

    {
        const  ::QString& a0def = QString();
        const  ::QString* a0 = &a0def;
        int a0State = 0;
         ::QObject* a1 = nullptr;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, NULL, sipUnused, "|J1JH", sipType_QString,&a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipKCoreConfigSkeleton(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return NULL;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_KCoreConfigSkeleton[] = {{8, 0, 1}};


static PyMethodDef methods_KCoreConfigSkeleton[] = {
    {SIP_MLNAME_CAST(sipName_addItem), meth_KCoreConfigSkeleton_addItem, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemBool), meth_KCoreConfigSkeleton_addItemBool, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemDateTime), meth_KCoreConfigSkeleton_addItemDateTime, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemDouble), meth_KCoreConfigSkeleton_addItemDouble, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemInt), meth_KCoreConfigSkeleton_addItemInt, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemInt64), meth_KCoreConfigSkeleton_addItemInt64, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemIntList), meth_KCoreConfigSkeleton_addItemIntList, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemLongLong), meth_KCoreConfigSkeleton_addItemLongLong, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemPassword), meth_KCoreConfigSkeleton_addItemPassword, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemPath), meth_KCoreConfigSkeleton_addItemPath, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemPoint), meth_KCoreConfigSkeleton_addItemPoint, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemProperty), meth_KCoreConfigSkeleton_addItemProperty, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemRect), meth_KCoreConfigSkeleton_addItemRect, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemSize), meth_KCoreConfigSkeleton_addItemSize, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemString), meth_KCoreConfigSkeleton_addItemString, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemStringList), meth_KCoreConfigSkeleton_addItemStringList, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemUInt), meth_KCoreConfigSkeleton_addItemUInt, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemUInt64), meth_KCoreConfigSkeleton_addItemUInt64, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemULongLong), meth_KCoreConfigSkeleton_addItemULongLong, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_childEvent), (PyCFunction)meth_KCoreConfigSkeleton_childEvent, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_clearItems), meth_KCoreConfigSkeleton_clearItems, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_config), meth_KCoreConfigSkeleton_config, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_connectNotify), (PyCFunction)meth_KCoreConfigSkeleton_connectNotify, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_currentGroup), meth_KCoreConfigSkeleton_currentGroup, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_customEvent), (PyCFunction)meth_KCoreConfigSkeleton_customEvent, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_disconnectNotify), (PyCFunction)meth_KCoreConfigSkeleton_disconnectNotify, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_findItem), meth_KCoreConfigSkeleton_findItem, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_isImmutable), meth_KCoreConfigSkeleton_isImmutable, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_isSignalConnected), (PyCFunction)meth_KCoreConfigSkeleton_isSignalConnected, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_items), meth_KCoreConfigSkeleton_items, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_load), meth_KCoreConfigSkeleton_load, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_read), meth_KCoreConfigSkeleton_read, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_readConfig), meth_KCoreConfigSkeleton_readConfig, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_receivers), (PyCFunction)meth_KCoreConfigSkeleton_receivers, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_removeItem), meth_KCoreConfigSkeleton_removeItem, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_save), meth_KCoreConfigSkeleton_save, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_sender), (PyCFunction)meth_KCoreConfigSkeleton_sender, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_senderSignalIndex), (PyCFunction)meth_KCoreConfigSkeleton_senderSignalIndex, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_setCurrentGroup), meth_KCoreConfigSkeleton_setCurrentGroup, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_setDefaults), meth_KCoreConfigSkeleton_setDefaults, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_timerEvent), (PyCFunction)meth_KCoreConfigSkeleton_timerEvent, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_useDefaults), meth_KCoreConfigSkeleton_useDefaults, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_usrRead), (PyCFunction)meth_KCoreConfigSkeleton_usrRead, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrReadConfig), (PyCFunction)meth_KCoreConfigSkeleton_usrReadConfig, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrSave), (PyCFunction)meth_KCoreConfigSkeleton_usrSave, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrSetDefaults), (PyCFunction)meth_KCoreConfigSkeleton_usrSetDefaults, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrUseDefaults), (PyCFunction)meth_KCoreConfigSkeleton_usrUseDefaults, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrWriteConfig), (PyCFunction)meth_KCoreConfigSkeleton_usrWriteConfig, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_writeConfig), meth_KCoreConfigSkeleton_writeConfig, METH_VARARGS, NULL}
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_KCoreConfigSkeleton[] = {
    {"configChanged()", 0, 0, 0},
    {0, 0, 0, 0}
};


static pyqt5ClassPluginDef plugin_KCoreConfigSkeleton = {
    & ::KCoreConfigSkeleton::staticMetaObject,
    0,
    signals_KCoreConfigSkeleton,
    0
};


sipClassTypeDef sipTypeDef_KConfigCore_KCoreConfigSkeleton = {
    {
        -1,
        0,
        0,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_KCoreConfigSkeleton,
        {0},
        &plugin_KCoreConfigSkeleton
    },
    {
        sipNameNr_KCoreConfigSkeleton,
        {0, 0, 1},
        49, methods_KCoreConfigSkeleton,
        0, 0,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    supers_KCoreConfigSkeleton,
    0,
    init_type_KCoreConfigSkeleton,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    dealloc_KCoreConfigSkeleton,
    0,
    0,
    0,
    release_KCoreConfigSkeleton,
    cast_KCoreConfigSkeleton,
    0,
    0,
    0,
    0,
    0,
    0
};
